User guide
==========

Basic usage
-----------

.. grid:: 3

    .. grid-item-card::
       :link: installation.rst
       :text-align: center

       **Installation**

       .. image:: ../_static/icons/installation-light.svg
          :class: only-light
          :width: 40%
       .. image:: ../_static/icons/installation-dark.svg
          :class: only-dark
          :width: 40%

       ^^^
       Install Scitacean with Pip or Conda.


    .. grid-item-card::
       :link: downloading.ipynb
       :text-align: center

       **Downloading datasets**

       .. image:: ../_static/icons/cloud-download-light.svg
          :class: only-light
          :width: 40%
       .. image:: ../_static/icons/cloud-download-dark.svg
          :class: only-dark
          :width: 40%

       ^^^
       Basics for downloading datasets from SciCat and files from file storage.

    .. grid-item-card::
       :link: uploading.ipynb
       :text-align: center

       **Uploading datasets**

       .. image:: ../_static/icons/cloud-upload-light.svg
          :class: only-light
          :width: 40%
       .. image:: ../_static/icons/cloud-upload-dark.svg
          :class: only-dark
          :width: 40%

       ^^^
       Basics for uploading datasets to SciCat and files to file storage.

.. toctree::
   :hidden:

   installation
   downloading
   uploading

Advanced usage
--------------

.. grid:: 3

    .. grid-item-card::
       :link: testing.ipynb
       :text-align: center

       Testing
       ^^^
       Testing code with Scitacean without accessing a real SciCat server or filesystem.

    .. grid-item-card::
       :link: classes-and-concepts.rst
       :text-align: center

       Classes and concepts
       ^^^
       Overview of classes in Scitacean and how they are used to interact with SciCat.

.. toctree::
   :hidden:

   testing
   classes-and-concepts
